@@ -2,36 +2,27 @@ extern crate bindgen;
 
 use std::env;
 use std::path::Path;
-use std::process::Command;
 
 fn main() {
     let out_dir = env::var("OUT_DIR").expect("failed to get envvar OUT_DIR");
-
-    let emcc_output = Command::new("emcc")
-        .arg("--cflags")
-        .output()
-        .expect("failed to execute process");
-    if !emcc_output.status.success() {
-        panic!("failed to execute command: {}",
-               String::from_utf8_lossy(&emcc_output.stderr));
-    }
-
-    let clang_args = String::from_utf8_lossy(&emcc_output.stdout);
+    let emscripten_dir = env::var("EMSCRIPTEN").expect("failed to get envvar EMSCRIPTEN");
 
     let whitelist = "^_?em_|^_?emscripten_|^_?EM_|^_?EMSCRIPTEN_";
 
-    let mut builder = bindgen::builder()
+    let builder = bindgen::builder()
         .header("etc/emscripten.h")
         .generate_comments(true)
         .whitelisted_type(whitelist)
         .whitelisted_function(whitelist)
         .whitelisted_var(whitelist)
         .no_unstable_rust()
-        .use_core();
+        .use_core()
+        .clang_arg(format!("-I{}/system/include", emscripten_dir))
+        .clang_arg("-x")
+        .clang_arg("c++")
+        .clang_arg("-std=c++11")
+        .clang_arg("-D__EMSCRIPTEN__");
 
-    for arg in clang_args.split_whitespace() {
-        builder = builder.clang_arg(arg);
-    }
 
     builder.generate()
         .expect("failed to generate rust bindings")
